@@ -41,7 +41,11 @@
 
 #include <FL/Fl_Tabs.H>
 #include <FL/Fl_Button.H>
+#include <FL/Fl_Check_Button.H>
 #include <FL/Fl_Return_Button.H>
+#include <FL/Fl_Round_Button.H>
+#include <FL/Fl_Int_Input.H>
+#include <FL/Fl_Choice.H>
 
 using namespace std;
 using namespace rdr;
@@ -67,6 +71,7 @@ OptionsDialog::OptionsDialog()
     createCompressionPage(tx, ty, tw, th);
     createSecurityPage(tx, ty, tw, th);
     createInputPage(tx, ty, tw, th);
+    createScreenPage(tx, ty, tw, th);
     createMiscPage(tx, ty, tw, th);
   }
 
@@ -247,8 +252,8 @@ void OptionsDialog::loadOptions(void)
     }
   }
 
-  caInput->value(CSecurityTLS::x509ca);
-  crlInput->value(CSecurityTLS::x509crl);
+  caInput->value(CSecurityTLS::X509CA);
+  crlInput->value(CSecurityTLS::X509CRL);
 
   handleX509(encX509Checkbox, this);
 #endif
@@ -269,9 +274,29 @@ void OptionsDialog::loadOptions(void)
     if (!strcmp(getMenuKeySymbols()[i].name, menuKeyBuf))
       menuKeyChoice->value(i + 1);
 
+  /* Screen */
+  int width, height;
+
+  if (sscanf(desktopSize.getValueStr(), "%dx%d", &width, &height) != 2) {
+    desktopSizeCheckbox->value(false);
+    desktopWidthInput->value("1024");
+    desktopHeightInput->value("768");
+  } else {
+    char buf[32];
+    desktopSizeCheckbox->value(true);
+    snprintf(buf, sizeof(buf), "%d", width);
+    desktopWidthInput->value(buf);
+    snprintf(buf, sizeof(buf), "%d", height);
+    desktopHeightInput->value(buf);
+  }
+  remoteResizeCheckbox->value(remoteResize);
+  fullScreenCheckbox->value(fullScreen);
+  fullScreenAllMonitorsCheckbox->value(fullScreenAllMonitors);
+
+  handleDesktopSize(desktopSizeCheckbox, this);
+
   /* Misc. */
   sharedCheckbox->value(shared);
-  fullScreenCheckbox->value(fullScreen);
   dotCursorCheckbox->value(dotWhenNoCursor);
 }
 
@@ -339,8 +364,8 @@ void OptionsDialog::storeOptions(void)
 
   SecurityClient::secTypes.setParam(security.ToString());
 
-  CSecurityTLS::x509ca.setParam(caInput->value());
-  CSecurityTLS::x509crl.setParam(crlInput->value());
+  CSecurityTLS::X509CA.setParam(caInput->value());
+  CSecurityTLS::X509CRL.setParam(crlInput->value());
 #endif
 
   /* Input */
@@ -356,9 +381,24 @@ void OptionsDialog::storeOptions(void)
     menuKey.setParam(menuKeyChoice->text());
   }
 
+  /* Screen */
+  int width, height;
+
+  if (desktopSizeCheckbox->value() &&
+      (sscanf(desktopWidthInput->value(), "%d", &width) == 1) &&
+      (sscanf(desktopHeightInput->value(), "%d", &height) == 1)) {
+    char buf[64];
+    snprintf(buf, sizeof(buf), "%dx%d", width, height);
+    desktopSize.setParam(buf);
+  } else {
+    desktopSize.setParam("");
+  }
+  remoteResize.setParam(remoteResizeCheckbox->value());
+  fullScreen.setParam(fullScreenCheckbox->value());
+  fullScreenAllMonitors.setParam(fullScreenAllMonitorsCheckbox->value());
+
   /* Misc. */
   shared.setParam(sharedCheckbox->value());
-  fullScreen.setParam(fullScreenCheckbox->value());
   dotWhenNoCursor.setParam(dotCursorCheckbox->value());
 
   std::map<OptionsCallback*, void*>::const_iterator iter;
@@ -374,7 +414,7 @@ void OptionsDialog::createCompressionPage(int tx, int ty, int tw, int th)
 
   int orig_tx, orig_ty;
   int half_width, full_width;
-  int width, height;
+  int height;
 
   tx += OUTER_MARGIN;
   ty += OUTER_MARGIN;
@@ -406,8 +446,6 @@ void OptionsDialog::createCompressionPage(int tx, int ty, int tw, int th)
     tx += GROUP_MARGIN;
     ty += GROUP_MARGIN;
 
-    width = encodingGroup->w() - GROUP_MARGIN * 2;
-
     tightButton = new Fl_Round_Button(LBLRIGHT(tx, ty,
                                                RADIO_MIN_WIDTH,
                                                RADIO_HEIGHT,
@@ -456,8 +494,6 @@ void OptionsDialog::createCompressionPage(int tx, int ty, int tw, int th)
     tx += GROUP_MARGIN;
     ty += GROUP_MARGIN;
 
-    width = colorlevelGroup->w() - GROUP_MARGIN * 2;
-
     fullcolorCheckbox = new Fl_Round_Button(LBLRIGHT(tx, ty,
                                                      RADIO_MIN_WIDTH,
                                                      RADIO_HEIGHT,
@@ -676,9 +712,9 @@ void OptionsDialog::createInputPage(int tx, int ty, int tw, int th)
 
   menuKeyChoice = new Fl_Choice(LBLLEFT(tx, ty, 150, CHOICE_HEIGHT, _("Menu key")));
 
-  menuKeyChoice->add(_("None"), 0, NULL, (void*)0, FL_MENU_DIVIDER);
+  fltk_menu_add(menuKeyChoice, _("None"), 0, NULL, (void*)0, FL_MENU_DIVIDER);
   for (int i = 0; i < getMenuKeySymbolCount(); i++)
-    menuKeyChoice->add(getMenuKeySymbols()[i].name, 0, NULL, 0, 0);
+    fltk_menu_add(menuKeyChoice, getMenuKeySymbols()[i].name, 0, NULL, 0, 0);
 
   ty += CHOICE_HEIGHT + TIGHT_MARGIN;
 
@@ -686,6 +722,50 @@ void OptionsDialog::createInputPage(int tx, int ty, int tw, int th)
 }
 
 
+void OptionsDialog::createScreenPage(int tx, int ty, int tw, int th)
+{
+  int x;
+
+  Fl_Group *group = new Fl_Group(tx, ty, tw, th, _("Screen"));
+
+  tx += OUTER_MARGIN;
+  ty += OUTER_MARGIN;
+
+  desktopSizeCheckbox = new Fl_Check_Button(LBLRIGHT(tx, ty,
+                                                     CHECK_MIN_WIDTH,
+                                                     CHECK_HEIGHT,
+                                                     _("Resize remote session on connect")));
+  desktopSizeCheckbox->callback(handleDesktopSize, this);
+  ty += CHECK_HEIGHT + TIGHT_MARGIN;
+
+  desktopWidthInput = new Fl_Int_Input(tx + INDENT, ty, 50, INPUT_HEIGHT);
+  x = desktopWidthInput->x() + desktopWidthInput->w() + \
+      gui_str_len("x") + 3 * 2;
+  desktopHeightInput = new Fl_Int_Input(x, ty, 50, INPUT_HEIGHT, "x");
+  ty += INPUT_HEIGHT + TIGHT_MARGIN;
+
+  remoteResizeCheckbox = new Fl_Check_Button(LBLRIGHT(tx, ty,
+                                                      CHECK_MIN_WIDTH,
+                                                      CHECK_HEIGHT,
+                                                      _("Resize remote session to the local window")));
+  ty += CHECK_HEIGHT + TIGHT_MARGIN;
+
+  fullScreenCheckbox = new Fl_Check_Button(LBLRIGHT(tx, ty,
+                                                  CHECK_MIN_WIDTH,
+                                                  CHECK_HEIGHT,
+                                                  _("Full-screen mode")));
+  ty += CHECK_HEIGHT + TIGHT_MARGIN;
+
+  fullScreenAllMonitorsCheckbox = new Fl_Check_Button(LBLRIGHT(tx + INDENT, ty,
+                                                      CHECK_MIN_WIDTH,
+                                                      CHECK_HEIGHT,
+                                                      _("Enable full-screen mode over all monitors")));
+  ty += CHECK_HEIGHT + TIGHT_MARGIN;
+
+  group->end();
+}
+
+
 void OptionsDialog::createMiscPage(int tx, int ty, int tw, int th)
 {
   Fl_Group *group = new Fl_Group(tx, ty, tw, th, _("Misc."));
@@ -699,12 +779,6 @@ void OptionsDialog::createMiscPage(int tx, int ty, int tw, int th)
                                                   _("Shared (don't disconnect other viewers)")));
   ty += CHECK_HEIGHT + TIGHT_MARGIN;
 
-  fullScreenCheckbox = new Fl_Check_Button(LBLRIGHT(tx, ty,
-                                                  CHECK_MIN_WIDTH,
-                                                  CHECK_HEIGHT,
-                                                  _("Full-screen mode")));
-  ty += CHECK_HEIGHT + TIGHT_MARGIN;
-
   dotCursorCheckbox = new Fl_Check_Button(LBLRIGHT(tx, ty,
                                                   CHECK_MIN_WIDTH,
                                                   CHECK_HEIGHT,
@@ -769,6 +843,19 @@ void OptionsDialog::handleX509(Fl_Widget *widget, void *data)
 }
 
 
+void OptionsDialog::handleDesktopSize(Fl_Widget *widget, void *data)
+{
+  OptionsDialog *dialog = (OptionsDialog*)data;
+
+  if (dialog->desktopSizeCheckbox->value()) {
+    dialog->desktopWidthInput->activate();
+    dialog->desktopHeightInput->activate();
+  } else {
+    dialog->desktopWidthInput->deactivate();
+    dialog->desktopHeightInput->deactivate();
+  }
+}
+
 void OptionsDialog::handleCancel(Fl_Widget *widget, void *data)
 {
   OptionsDialog *dialog = (OptionsDialog*)data;
